SWDEV-339113 - Update sampl codes with correct kernel coordinate (#2704)

Change-Id: Ibfc0fd285441cd3d79b312d2b739729a039a6f84
This commit is contained in:
ROCm CI Service Account
2022-06-02 17:07:52 +05:30
zatwierdzone przez GitHub
rodzic f6f8a0d144
commit e6ded45898
14 zmienionych plików z 47 dodań i 47 usunięć
@@ -37,8 +37,8 @@ THE SOFTWARE.
__global__ void matrixTranspose(float* out, float* in, const int width) {
extern __shared__ float sharedMem[];
int x = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
int y = hipBlockDim_y * hipBlockIdx_y + hipThreadIdx_y;
int x = blockDim.x * blockIdx.x + threadIdx.x;
int y = blockDim.y * blockIdx.y + threadIdx.y;
sharedMem[y * width + x] = in[x * width + y];